@@ -1,8 +1,8 @@
-from os import environ, path
+from os import environ
 import warnings
 from typing import Optional, Tuple, List, Union
-from enum import Enum, unique
 import itertools
+from mp_api.routes.charge_density.models import ChgcarDataDoc
 
 from pymatgen.core import Structure
 from pymatgen.io.vasp import Chgcar
@@ -11,7 +11,7 @@ from pymatgen.analysis.magnetism import Ordering
 from pymatgen.analysis.wulff import WulffShape
 from emmet.core.mpid import MPID
 from emmet.core.symmetry import CrystalSystem
-from emmet.core.vasp.calc_types import TaskType, CalcType
+from emmet.core.vasp.calc_types import CalcType
 from emmet.core.settings import EmmetSettings
 
 from mp_api.core.client import BaseRester, MPRestError
@@ -66,7 +66,8 @@ class MPRester:
     electronic_structure_dos: DosRester
     oxidation_states: OxidationStatesRester
     provenance: ProvenanceRester
-    user_settings: UserSettingsRester
+    _user_settings: UserSettingsRester
+    _general_store: GeneralStoreRester
 
     def __init__(
         self,
@@ -133,7 +134,9 @@ class MPRester:
             self._all_resters.append(rester)
 
             setattr(
-                self, cls.suffix.replace("/", "_"), rester,  # type: ignore
+                self,
+                cls.suffix.replace("/", "_"),  # type: ignore
+                rester,
             )
 
     def __enter__(self):
@@ -737,15 +740,18 @@ class MPRester:
         millers, energies = zip(*miller_energy_map.items())
         return WulffShape(lattice, millers, energies)
 
-    def get_charge_density_from_material_id(self, material_id: str) -> Optional[Chgcar]:
+    def get_charge_density_from_material_id(
+        self, material_id: str, inc_task_doc: bool = False
+    ) -> Optional[Chgcar]:
         """
         Get charge density data for a given Materials Project ID.
 
         Arguments:
             material_id (str): Material Project ID
+            inc_task_doc (bool): Whether to include the task document in the returned data.
 
         Returns:
-            chgcar: Pymatgen CHGCAR object.
+            chgcar: Pymatgen Chgcar object.
         """
 
         # TODO: really we want a recommended task_id for charge densities here
@@ -753,13 +759,22 @@ class MPRester:
         task_ids = self.get_task_ids_associated_with_material_id(
             material_id, calc_types=[CalcType.GGA_Static, CalcType.GGA_U_Static]
         )
-        results = self.charge_density.search(task_ids=task_ids)
+        results: List[ChgcarDataDoc] = self.charge_density.search(task_ids=task_ids)  # type: ignore
 
-        latest_doc = sorted(results, key=lambda x: x.last_updated, reverse=True)[0]
+        if len(results) == 0:
+            return None
 
-        result = self.charge_density.get_data_by_id(latest_doc.fs_id)  # type: ignore
+        latest_doc = max(results, key=lambda x: x.last_updated)
 
-        if result:
-            return result.data
+        chg_doc = self.charge_density.get_data_by_id(latest_doc.fs_id)
+
+        if chg_doc:
+            chgcar = chg_doc.data
+            task_doc = self.tasks.get_data_by_id(latest_doc.task_id)
+            if inc_task_doc:
+                return chgcar, task_doc
+            return chgcar
         else:
-            raise MPRestError("No charge density found")
+            raise MPRestError(
+                "Charge density task_id found but no charge density fetched."
+            )
