@@ -1,12 +1,12 @@
 from emmet.core.symmetry import CrystalSystem
 from emmet.core.vasp.calc_types import CalcType
+from mp_api.routes.tasks.models import TaskDoc
 import pytest
 import random
 import os
 import typing
 from mp_api.matproj import MPRester
 from mp_api.core.settings import MAPISettings
-import requests
 
 from pymatgen.io.cif import CifParser
 from pymatgen.electronic_structure.bandstructure import (
@@ -50,7 +50,7 @@ class TestMPRester:
 
     def test_get_database_version(self, mpr):
         db_version = mpr.get_database_version()
-        assert db_version == MAPISettings().db_version
+        assert db_version == MAPISettings().DB_VERSION
 
     def test_get_materials_id_from_task_id(self, mpr):
         assert mpr.get_materials_id_from_task_id("mp-540081") == "mp-19017"
@@ -79,7 +79,7 @@ class TestMPRester:
         assert len(structs) > 0
 
     def test_find_structure(self, mpr):
-        path = os.path.join(MAPISettings().test_files, "Si_mp_149.cif")
+        path = os.path.join(MAPISettings().TEST_FILES, "Si_mp_149.cif")
         with open(path) as file:
             data = mpr.find_structure(path)
             assert len(data) > 0
@@ -142,6 +142,12 @@ class TestMPRester:
         chgcar = mpr.get_charge_density_from_material_id("mp-149")
         assert isinstance(chgcar, Chgcar)
 
+        chgcar, task_doc = mpr.get_charge_density_from_material_id(
+            "mp-149", inc_task_doc=True
+        )
+        assert isinstance(chgcar, Chgcar)
+        assert isinstance(task_doc, TaskDoc)
+
     def test_get_wulff_shape(self, mpr):
         ws = mpr.get_wulff_shape("mp-126")
         assert isinstance(ws, WulffShape)
